@@ -832,18 +832,21 @@ class FileHDFio(object):
                     item_abs_lst = os.path.normpath(item).replace("\\", "/").split("/")
                 else:  # relative HDF5 path
                     item_abs_lst = (
-                        os.path.normpath(os.path.join(self.h5_path, item))
+                        os.path.normpath(os.path.join('.' + self.h5_path, item))
                         .replace("\\", "/")
                         .split("/")
                     )
-                    # print(item, item_abs_lst)
-                    # item_abs_lst = os.path.normpath(os.path.join(self.h5_path, item)).replace('\\', '/').split("/")
+                # print('h5_path=', self.h5_path, 'item=', item, 'item_abs_lst=', item_abs_lst)
                 if (
-                    item_abs_lst[1] == "" and len(item_abs_lst) == 2
+                    item_abs_lst[0] == ".." and len(item_abs_lst) == 1
                 ):  # leaving the HDF5 file
                     return self._create_project_from_hdf5()
-                elif item_abs_lst[1] == "":
-                    return self._create_project_from_hdf5()["/".join(item_abs_lst[2:])]
+                elif item_abs_lst[0] == "..":
+                    return self._create_project_from_hdf5()["/".join(item_abs_lst[1:])]
+                elif item_abs_lst[0] == '.':
+                    hdf_object = self.copy()
+                    hdf_object.h5_path = "/"
+                    return hdf_object
                 else:
                     hdf_object = self.copy()
                     hdf_object.h5_path = "/".join(item_abs_lst[:-1])
